#! /usr/bin/python

## Copyright (C) 2008-2015 Red Hat, Inc.
## Copyright (C) 2008-2015 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sys

SWITCHDISPLAYMANAGERDIR = '/usr/share/system-switch-displaymanager/'
ICONDIR = SWITCHDISPLAYMANAGERDIR + '/pixmaps/'

if not SWITCHDISPLAYMANAGERDIR in sys.path:
    sys.path.append(SWITCHDISPLAYMANAGERDIR)

import signal
import os
import os.path
import string
import gettext
from backend import *


##
## I18N
##
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)
try:
    gettext.install(PROGNAME, '/usr/share/locale', 1)
except IOError:
    import __builtin__
    __builtin__.__dict__['_'] = unicode    

try:
    import pygtk
    pygtk.require("2.0")
except:
    pass
try:
    import gtk
    import gtk.glade
except:
    sys.exit(1)

class mainDialog:
    def __init__(self):
        self.cdm = DM
        self.dmlist = DMLIST
        self.defaultw = getDefaultDM()
        self.dm = DISPLAYMANAGERS[self.defaultw][OPTION_NAME]

    def main(self):
        glade_file = PROGNAME + '.glade'

        if not os.path.isfile(glade_file):
            glade_file = GLADEPATH + glade_file
        if not os.path.isfile(glade_file):
            glade_file = SWITCHDISPLAYMANAGERDIR + glade_file

        self.xml = gtk.glade.XML(glade_file, None, domain=PROGNAME)

        self.xml.signal_autoconnect(
            {
            'on_cancelB_clicked' : self.on_cancelB_clicked,
            'on_okB_clicked' : self.on_okB_clicked,
            'on_gdmRB_clicked' : (self.on_RB_clicked, GDM),
            'on_kdmRB_clicked' : (self.on_RB_clicked, KDM),
            'on_xdmRB_clicked' : (self.on_RB_clicked, XDM),
            'on_wdmRB_clicked' : (self.on_RB_clicked, WDM),
            'on_lightdmRB_clicked' : (self.on_RB_clicked, LIGHTDM),
            'on_lxdmRB_clicked' : (self.on_RB_clicked, LXDM),
            'on_sddmRB_clicked' : (self.on_RB_clicked, SDDM),
            })

        self.window = self.xml.get_widget('window')
        self.image = self.xml.get_widget('Image')
        self.window.connect('delete-event', self.on_Dialog_delete_event)
        self.window.connect('hide', gtk.main_quit)
        self.xml.get_widget('desktopImage').set_from_file(ICONDIR+PROGNAME+'.png')
        self.hydrate()
        gtk.main()
        
    def on_Dialog_delete_event(self, *args):
        gtk.main_quit()

    def on_cancelB_clicked(self, button):
        gtk.main_quit()

    def on_okB_clicked(self, button):
        self.window.hide()

        if os.system(SWITCHDISPLAYMANAGERDIR + HELPER + ' ' + self.dm):
            self.warningDialog()
        else:
            self.infoDialog()

        gtk.main_quit()

    def on_RB_clicked(self, button, w):
        self.image.set_from_file(ICONDIR+DISPLAYMANAGERS[w][ICON_NAME])
        self.dm = DISPLAYMANAGERS[w][OPTION_NAME]

    def hydrate(self):
        self.window.set_title(_('Display Manager Switcher'))
        self.xml.get_widget('titleLabel').set_text(TEXT)
        self.xml.get_widget('frameLabel').set_label(_('Available Display Managers'))
        self.hydrate_dm()

    def hydrate_dm(self):
        for w in DISPLAYMANAGERS.keys():
           if w in self.dmlist:
              self.xml.get_widget(DISPLAYMANAGERS[w][WIDGET_NAME]).show()
           else:
              self.xml.get_widget(DISPLAYMANAGERS[w][WIDGET_NAME]).hide()
        if self.cdm in DISPLAYMANAGERS.keys():
           self.xml.get_widget(DISPLAYMANAGERS[self.cdm][WIDGET_NAME]).set_active(TRUE)
           self.dm = DISPLAYMANAGERS[self.cdm][OPTION_NAME]
           self.xml.get_widget('Image').set_from_file(ICONDIR+DISPLAYMANAGERS[self.dm][ICON_NAME])
        else:
           self.xml.get_widget(DISPLAYMANAGERS[self.defaultw][WIDGET_NAME]).set_active(TRUE)
           self.dm = DISPLAYMANAGERS[self.defaultw][OPTION_NAME]
           self.xml.get_widget('Image').set_from_file(ICONDIR+DISPLAYMANAGERS[self.defaultw][ICON_NAME])

    def infoDialog(self):
        dlg = gtk.MessageDialog(self.window,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                INFO_TEXT)
        
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()

    def warningDialog(self):
        dlg = gtk.MessageDialog(self.window,
                                gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                                gtk.MESSAGE_INFO,
                                gtk.BUTTONS_OK,
                                WARNING_TEXT)
        dlg.set_position (gtk.WIN_POS_MOUSE)
        dlg.run()
        dlg.destroy()


# make ctrl-C work
if __name__ == '__main__':
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    dlg = mainDialog().main()
    
    sys.exit(0)
